@@ -1,12 +1,10 @@
+{-# LANGUAGE OverloadedStrings #-}
 module Main where
 
 import Graphics.UI.Gtk
-import Control.Concurrent.MVar
-import Control.Monad ( liftM )
-import Data.Maybe ( fromMaybe )
 import Data.List ( findIndex )
 import Control.Monad.IO.Class (MonadIO(..))
-
+import qualified Data.Text as T
 
 main = do
   initGUI
@@ -18,7 +16,7 @@ main = do
   comboBoxSetModelText combo
 
   mapM_ (comboBoxAppendText combo)
-    (words "ice-cream turkey pasta sandwich steak")
+    (T.words "ice-cream turkey pasta sandwich steak")
 
   -- select the first item
   comboBoxSetActive combo 0
